@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 BEGIN {
-  $CPAN::Perl::Releases::VERSION = '0.10';
+  $CPAN::Perl::Releases::VERSION = '0.12';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -229,6 +229,10 @@ our $data =
     "tar.bz2" => "J/JE/JESSE/perl-5.14.0.tar.bz2",
     "tar.gz" => "J/JE/JESSE/perl-5.14.0.tar.gz"
   },
+  "5.14.1-RC1" => {
+    "tar.bz2" => "J/JE/JESSE/perl-5.14.1-RC1.tar.bz2",
+    "tar.gz" => "J/JE/JESSE/perl-5.14.1-RC1.tar.gz"
+  },
   "5.6.0" => {
     "tar.gz" => "G/GS/GSAR/perl-5.6.0.tar.gz"
   },
@@ -345,7 +349,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.10
+version 0.12
 
 =head1 SYNOPSIS
 
